/* ==============================================================================
Project: 	   	Master do-file to run the analysis for the ETR report in Honduras

Authors:		Thiago Scot
				Pierre Bachas
				Santiago Cesteros
				Tatiana Flores
				Gabriel Oqueli
-------------------------------------------------------------------------------
Creation Date:          November 8th, 2024  
Last update:          	December 12th, 2024         
=============================================================================== */

drop _all
clear all
set more off
set varabbrev off
set seed 2533


/* ------------------------------------------------------------------------------
                                  0: Set locals and Paths
------------------------------------------------------------------------------- */

/* Change global path before replication */
global path 		"C:\Users\wb558768\Downloads\rep-checks\240\Replication ETR HND Note"

global databases 	"$path/data"
global output 		"$path/output"
global figures 		"$output/figures"
global tables 		"$output/tables"
global do 			"$path/code"


sysdir set PLUS "$do/ado"

local user_commands gtools egenmore wid
foreach command of local user_commands {
	cap which `command'
	if _rc == 111 {
		ssc install `command', replace
	}
}

/*==============================================================================
							1: Data Creation
==============================================================================*/

/* Measure time */
scalar t1 = c(current_time)
local time1=t1

* ----------------------------------------- 1.1: Tax data ------------------------------------------

include "$do/1a_RentalCapGains"							// CSV Capital Gains and Rental Income
include "$do/1b_GenderData"								// CSV gender data
include "$do/1cc_CIT_clean"								// CSV CIT data
include "$do/1c_UndistributedProfits"					// Preparing CIT + shareholder list to compute undist profits
include "$do/1d_Inequality_Clean_loop"					// From csv to Stata (2011-2019)
include "$do/1e_Inequality_Clean_2003_2010"				// From csv to Stata (2003-2010)

* ----------------------------------------- 1.2: Tax variables --------------------------------------

include "$do/2a_Inequality_CreateVars_loop"				// Create key variables on tax data

* ----------------------------------------- 1.3: Shareholders data ----------------------------------

include "$do/3a_PrepareForDescriptives" 				// Creation of datasets used generate Figure 4 (F4 data)

/*==============================================================================
							2: Analysis
==============================================================================*/

/* Measure time */
scalar t2 = c(current_time)
local time2=t2

/* ----------------- */
/* TOP 1.5% ANALYSIS */
/* ----------------- */

include "$do/Effective_Tax_Rates_top15_intervals"  		// Figure 1, Figure 2, Figure 3, Figure 5, and Figure A1

/* ------- */
/* TABLE 1 */
/* ------- */

include "$do/Effective_Tax_Rates_Other" 				// Table 1

/* --------------------------------- */
/* SHAREHOLDERS ANALYSIS (SECTION 5) */
/* --------------------------------- */

include "$do/3b_DescriptivesPJ"							// Figure 4

/* Measure time */
scalar t3 = c(current_time)
local time3=t3

/* Display time */
di "`time1'"
di "`time2'"
di "`time3'"

/*==============================================================================
					3: ERASE INTERMEDIATE & NOT USED FILES
==============================================================================*/

erase "$databases/Output/ShareholdersData/shareholder_PJlevel.dta"
erase "$databases/Output/Auxiliary/CIT_clean.dta"
erase "$databases/Output/Auxiliary/UndistributedProfits_individual.dta"
erase "$databases/Output/Auxiliary/UndistributedProfits_relation.dta"

foreach year in 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2014 2015 2017 2020 {
	erase "$databases/Output/AnalysisTaxData/TaxData_Analysis_`year'.dta"
}
