*===============================================================================
* File name: 		1b_GenderData.do
* 
* Description:		This do-file creates Gender_age_dataset.dta dataset, which 
*					contains gender information at the individual level and is
*					used as intermediate dataset in the 1d_Inequality_Clean_loop 
*					and 1e_Inequality_Clean_2003_2010 do files.
*
* Input:  					
*					$databases/Inputs/RawTaxData/Desigualdad_Jan23/Base_Edad_Genero.csv
*
* Output:
*					$databases/Output/CleanTaxData/Gender_age_dataset.dta
*===============================================================================

di in red "Loading and cleaning gender data"

import delimited "$databases/Inputs/RawTaxData/Desigualdad_Jan23/Base_Edad_Genero.csv", clear encoding(UTF-8)

	
	
gen female = (genero == "FEMENINO")
lab def female 1 "Female" 0 "Male"
lab val female female

gen date_aux = substr(fecha_nacimiento,1,4) + "/" + substr(fecha_nacimiento,6,2) + "/" + substr(fecha_nacimiento,9,2)
gen birth_date = date(date_aux, "YMD")
format birth_date %td
drop date_aux

gen birth_year = year(birth_date)
encode rnp_estado_civil, gen(marital_status)

order id female birth_date birth_year marital_status 

gen age_2018 = 2018 - birth_year

/* Generate current age */
gen today = "`c(current_date)'"
replace today = subinstr(today, " ", "-",.)
gen date_today = date(today, "DMY")
format date_today %td
*gen age_today = age(birth_date, date_today)

drop fecha_nacimiento rnp_estado_civil rnp_estado edad genero rnp_domicilio rnp_ciudad birth_date
drop if id == .
save "$databases/Output/CleanTaxData/Gender_age_dataset.dta", replace

