*===============================================================================
* File name: 		1c_UndistributedProfits.do
* 
* Description:		This do-file creates the UndistributedProfits_relation.dta 
*					and the UndistributedProfits_individual datasets, which 
*					are used as intermediate datasets in the 
*					1e_Inequality_Clean_2003_2010, 1d_Inequality_Clean_loop,
*					and the Aux_CorporateMacroAggregates do files.
*
* Input:  					
*					$databases/Inputs/AuxData/clean_shareholder_list_IndividualOnly.dta
*					$databases/Inputs/RawTaxData/DMR_113_v2.csv
*					$databases/Output/Auxiliary/CIT_clean.dta
*
* Output:
*					$databases/Output/Auxiliary/UndistributedProfits_relation.dta
*					$databases/Output/Auxiliary/UndistributedProfits_individual.dta
*===============================================================================


*Start with shareholder list
use  "$databases/Inputs/AuxData/clean_shareholder_list_IndividualOnly.dta", clear

keep id_informante id_informado adjusted_share informado_nature

/* Check variables */
summ adjusted_share
count if adjusted_share>1

*First will get info on distributed dividends (should be netted out from corporate profits
preserve

	import delimited "$databases/Inputs/RawTaxData/DMR_113_v2.csv", encoding(utf8) clear
	rename año year
	
	keep id year no_rel base_retencion_dmr
	
	tempfile dividend
	save "`dividend'"
	
	use  "$databases/Output/Auxiliary/CIT_clean.dta", clear
	
	merge 1:1 id year using "`dividend'"
	tab year _merge
	
	drop if _merge == 2
	drop _merge
	
	*Netting out dividends from profits
	replace base_retencion_dmr = 0 if (base_retencion_dmr == .)
	gen double profit_net_div = taxable_profit - base_retencion_dmr
	
	
	rename (id) (id_informante)
	
	gen top_decile = (percentile_turnover_cit >= 90)

	keep id_informante year turnover no_rel taxable_profit profit_net_div top_decile impuesto_causado exonerado 
	*dataset will come long, we reshape wide to merge to shareholder dataset
	reshape wide  turnover no_rel taxable_profit profit_net_div top_decile impuesto_causado exonerado, i(id_informante) j(year)
	
	tempfile pj_data
	save "`pj_data'"
	
restore

merge m:1 id_informante using "`pj_data'"

keep if _merge == 3				//now we drop both firms without shareholders and shareholders without ISRPJ data


reshape long  turnover no_rel taxable_profit profit_net_div top_decile impuesto_causado exonerado, i(id_informante id_informado) j(year)

// Key income variable: share of corporate profit attributable to each shareholder, according to their ownership share
gen undistributed_corp_income = adjusted_share*profit_net_div					
gen undistributed_corp_taxes  = adjusted_share*impuesto_causado

drop _merge

*Only need to keep when we observe profits in CIT
drop if undistributed_corp_income == .

save "$databases/Output/Auxiliary/UndistributedProfits_relation.dta", replace		//save database at shareholder-by-corporation level

preserve
	drop if id_informado == .		//Drop observations deleted for which we do not observe id of receiving end
	
	gen large_shareholder = (adjusted_share >= 0.05 & adjusted_share != .)
	gen profit_losses     = (undistributed_corp_income < 0)
	gen large_share_firm  = (large_shareholder == 1 & top_decile == 1)
	
	gen positive_profits = undistributed_corp_income if undistributed_corp_income > 0
	gen positive_profits_exempt = positive_profits if (exonerado == 1)
	
	
	gcollapse (sum) undistributed_corp_income undistributed_corp_taxes number_corps_largeshare = large_shareholder positive_profits positive_profits_exempt ///
			  (max) large_shareholder profit_losses large_share_firm exempt_any = exonerado ///
			  (count) number_corps = id_informante , by(id_informado year)
	
	gen total_profit_losses = undistributed_corp_income < 0
	gen share_profits_exempt = positive_profits_exempt/positive_profits
	
	
	rename id_informado id
	save "$databases/Output/Auxiliary/UndistributedProfits_individual.dta", replace	//save database consolidating all profits by shareholder only
restore

