*===============================================================================
* File name: 		1e_Inequality_Clean_2003_2010.do
* 
* Description:		This do-file creates the TaxData_`year'.dta datasets for the 
*					2003-2010 period, which contain inequality measures related 
*					data and are used as intermediate datasets in the 
*					2d_inequality_createvars_loop do file.
*
* Input:  					
*					$databases/Inputs/RawTaxData/Desigualdad_Jan23/21012023_2003_2010.csv
*					$databases/Output/CleanTaxData/CapitalGains.dta
*					$databases/Output/CleanTaxData/RentalIncome.dta
*					$databases/Output/Auxiliary/UndistributedProfits_individual.dta
*					$databases/Output/CleanTaxData/Gender_age_dataset.dta
*
* Output:
*					$databases/Output/CleanTaxData/TaxData_`year'.dta
*===============================================================================

* Open csv and save as stata

quietly {
	di in red "Loading taxdata 2003-2010"
	
			
	import delimited "$databases/Inputs/RawTaxData/MostUpdated_Apr23/21012023_2003_2010.csv", clear

	
	rename ( año creretenanticipoirs creretenart50leyisr creretenfuenteasal ingresosnetosnograv ///
		ingresosactimercantiles ingresoshonoraprof ingresosinternobanc ingresosporactiart20 ///
		ingresosporalquileres ingresosporservicios ingresossueldossalaboni otrosingregravados ///
		totalinggravresulejer deducactimercantiles deduchonorarioprof deducotrosingregrav ///
		deducporactart20 deducporalquileres deducporinternobanc deducporservicios ///
		deducsueldossalboni totaldeducresulejer) ///
		( year cre_reten_anticipo_irs cre_reten_art50_ley_isr cre_reten_fuente_asal ///
		ingre_netos_no_grav ingre_acti_mercantiles ingre_honora_prof ingre_inter_no_banc ///
		ingre_por_acti_art20 ingre_por_alquileres ingre_por_servicios ingre_sueldos_sala_boni ///
		otros_ingre_gravados total_ing_grav_resul_ejer deduc_acti_mercantiles deduc_honorarios_prof ///
		deduc_otros_ingre_grav deduc_por_act_art20 deduc_por_alquileres deduc_por_inter_no_banc ///
		deduc_por_servicios deduc_sueldos_sal_boni total_deduc_resul_ejer) 
	
	*Dealing with duplicates: 128 duplicates in 2010, seem to be related to DMR; 8 fully repeated in 2005, so simple to drop
	*For 2010, we only keep observations with filed taxes since we have almost no DMR info for that year
	bys id year: gen N_rep = _N
	drop if N_rep == 2 & presenta_djisr == .
	duplicates drop *, force
	
	
		merge 1:1 id year using "$databases/Output/CleanTaxData/CapitalGains.dta"			//Merging rental income data
		drop if (_merge == 2 & !inrange(year, 2003,2010))
		drop _merge
		
		merge 1:1 id year using "$databases/Output/CleanTaxData/RentalIncome.dta"			//merging capital gains data
		drop if (_merge == 2 & !inrange(year, 2003,2010))
		drop _merge
		
		merge 1:1  id year using "$databases/Output/Auxiliary/UndistributedProfits_individual.dta"   //Merging undistributed profits
		drop if (_merge == 2 & !inrange(year, 2003,2010))
		drop _merge
	
	*Changing string variables to numeric + labels
	foreach var of varlist departamento municipio tipo_ot tamaño_ot id_sección d_macro_actividad d_division d_grupo d_clase {
		encode `var', gen(`var'_num)
		drop `var'
	}

	rename (departamento_num municipio_num tipo_ot_num tamaño_ot_num ) ///
		  (djisr_chr_departamento djisr_chr_municipio djisr_chr_tipo djisr_chr_size  )

	rename (id_division id_grupo id_clase id_sección_num d_macro_actividad_num d_division_num d_grupo_num d_clase_num) ///
			(act_div_code act_grupo_code act_class_code act_section act_macro act_division acg_grupo act_class)
			
	rename (atc  dmr_135 export_aduana total_informado_terceros) (tpi_atc   tpi_dmr_135 ///
			tpi_exports tpi_total)



		rename (cre_reten_anticipo_irs cre_reten_art50_ley_isr cre_reten_fuente_asal ingre_netos_no_grav total_deduc_resul_ejer ///
			total_ing_grav_resul_ejer  presenta_djisr) (djisr_cred_anticipo djisr_cred_art50 djisr_cred_wage djisr_nontaxable_income ///
			djisr_deductions djisr_gross_income djisr_dummy_filed)
		 
		rename (ingre_acti_mercantiles ingre_honora_prof ingre_inter_no_banc ingre_por_acti_art20 ingre_por_alquileres ///
				ingre_por_servicios ingre_sueldos_sala_boni otros_ingre_gravados) (djisr_income_commercial djisr_income_honorario djisr_income_interest ///
				djisr_income_art20 djisr_income_rents djisr_income_services djisr_income_wages djisr_income_other)
				
		rename (deduc_acti_mercantiles deduc_honorarios_prof deduc_por_inter_no_banc deduc_por_act_art20 deduc_por_alquileres ///
				 deduc_por_servicios deduc_sueldos_sal_boni deduc_otros_ingre_grav ) ///
				(djisr_deduction_commercial djisr_deduction_honorario djisr_deduction_interest ///
				djisr_deduction_art20 djisr_deduction_rents djisr_deduction_services djisr_deduction_wages djisr_deduction_other)

	lab var dmr_111 "111 RETENCIÓN EN LA FUENTE ASALARIADOS"
	lab var dmr_112 "112 RETENCIÓN POR SERVICIOS, HONORARIOS  (ART. 50)"
	lab var dmr_113 "113 RETENCIÓN POR DIVIDENDOS O UTILIDADES DISTRIBUIDAS (ART. 25)"
	lab var dmr_115 "115 RETENCIÓN POR INTERESES Y RENDIMIENTOS FINANACIEROS (ART. 9)"
	lab var tpi_atc "Ventas por Tarjetas de crédito o débito"
	lab var tpi_dmr_135 "RETENCIÓN ANTICIPO ISR 1%"
	lab var tpi_exports "Exportaciones que realizo el OT"
	lab var dmr_capitalgains "Income from Capital Gains"
	lab var dmr_rentalincome "Income from non-commercial rentals"
		
	order id year djisr_chr* djisr_income_* djisr* dmr_* tpi_* 
	
	merge m:1 id using  "$databases/Output/CleanTaxData/Gender_age_dataset.dta", nogen keep(1 3)
	
	compress

	foreach year of numlist 2003/2010 {
		di in red "Saving database for `year'"
		preserve
			keep if year == `year'
			save "$databases/Output/CleanTaxData/TaxData_`year'.dta", replace
		restore
	}
}

clear
