/* --------------------------------------------------------------------------- */
* File name: 		3a_PrepareForDescriptives.do
* 
* Description:		This do file creates the data needed to generate paper 
*					Figures 4 (a) and 4 (b)
*
* Input:  					
*					$data/clean_shareholder_list.dta
*					$data/DMR_113_v2.csv
*					$data/DJ_ISR.csv
*
* Output:			$data/shareholder_PJlevel.dta
*					$data/ISRPJ2021_withShareholderInfo.dta
*					
/* --------------------------------------------------------------------------- */

/* Load shareholder list */
use "$databases/Inputs/AuxData/clean_shareholder_list.dta", clear

/* Set dataset at PJ (informante) level */
preserve
	gen shareholder_pj = (informado_nature == 2)
	gen foreign_shareholder = (tipo_relacion == "SOCIO EXTRANJERO")
	gen valid_rtn = (id_informado != .)
	gen no_shares = (step == 0)

	gen n = 1
	gen n_valid	 	= 1 if valid_rtn 			== 1
	gen n_foreign 	= 1 if foreign_shareholder 	== 1
	gen n_pj 		= 1 if shareholder_pj 		== 1
	
	gen adjusted_share_foreign 	= (adjusted_share) 	if foreign_shareholder == 1
	gen adjusted_share_pj 		= (adjusted_share) 	if shareholder_pj == 1
	gen adjusted_share_valid   	= (adjusted_share) 	if valid_rtn == 1
	
	replace step = step - 1 if step >= 4
	
	order id_informante id_informado informado_nature tipo_relacion shareholder_pj foreign_shareholder valid_rtn adjusted_share adjusted_share_foreign adjusted_share_valid
	
	gcollapse (sum) adjusted_share n_shareholders = n n_shareholders_pj = shareholder_pj n_shareholders_foreign = foreign_shareholder ///
			  n_shareholders_valid = valid_rtn adjusted_share_foreign adjusted_share_valid adjusted_share_pj (first) step ///
			  (max) foreign_shareholder activo shareholder_pj no_shares valid_rtn, by(id_informante)
	
	
	order id_informante activo n_shareholders n_shareholders_pj adjusted_share adjusted_share_foreign ///
		adjusted_share_valid adjusted_share_pj step foreign_shareholder
	save "$databases/Output/ShareholdersData/shareholder_PJlevel.dta", replace
restore

/* --------------------- */
/* Import dividends data */
/* --------------------- */

preserve

	import delimited "$databases/Inputs/RawTaxData/DMR_113_v2.csv", encoding(utf8) clear
	rename año year
	
	keep id year no_rel base_retencion_dmr
	
	tempfile dividend
	save "`dividend'"
restore

/* -------------------- */
/* Import DJISR PJ data */
/* -------------------- */

preserve
	
	import delimited "$databases/Inputs/RawTaxData/DJ_ISR.csv", encoding(utf8) clear
	
	rename año year
	
	keep if inrange(year, 2021, 2021)
	
	merge 1:1 id year using "`dividend'"
	drop if _merge == 2
	drop _merge
	
	gen double check_profit = total_ingresos_resul_ejercicio-total_deduc_del_ejerc
	gen double profit = resultado_del_ejercicio - resul_ejer_perdida 

	replace base_retencion_dmr = 0 if (base_retencion_dmr == .)
	gen double profit_net_div = profit - base_retencion_dmr
	
	keep id year total_ingresos_resul_ejercicio total_activo_sf no_rel profit profit_net_div
	
	rename (id total_ingresos_resul_ejercicio total_activo_sf) ///
			(id_informante turnover assets)

			reshape wide  turnover assets no_rel profit profit_net_div, i(id_informante) j(year)
	
	tempfile pj_data
	save "`pj_data'"
	
restore

/* ----------------------------------- */
/* Add ISR PJ 2021 to shareholder data */
/* ----------------------------------- */
use  "$databases/Output/ShareholdersData/shareholder_PJlevel.dta", clear

merge 1:1 id_informante using  "`pj_data'"
ren _merge _m1

keep if _m1 != 1

save "$databases/Output/ShareholdersData/ISRPJ2021_withShareholderInfo.dta", replace