*===============================================================================
* File name: 		Appendix_TaxRecords.do
* 
* Description:		This do-file provides locals with information on the minimum
*					wage and the thresholds (tax brackets) for each category of 
*					the progressive income tax scheme for each year.
*
*===============================================================================

/* Setting year-specific minimum wages and tax brackets */

/*

Social Security contributions

	After 2015: Employer pays 8.5% (3.5% IVM + 5% Health) to state welfare + 1.5% for private contribution regime
				Employee pays 5% (2.5% IVM + 2.5% Health) to state welfare + 1.5% for private contribution regime
	All contributions are over base wage, which lies between minimum wage and ceiling defined yearly
	For IVM and Individual accounts: 8,882.30 per month (2015-2018)
	For Health: 7350 (2015), 7717.5 (2016), 8103.38 (2017), 8508.54 (2018)
	
	Before 2015 (Perdomo, 2011)	:
				Employer pays (2% IVM + 5% health)
				Employee pays (1% IVM + 2.5% health)
	Ceiling was 7000
	
*/

if inrange(`year', 2015,2020) { 
	local employer_rate = 0.1
	local worker_rate = 0.065
	local ceiling_contr = 12*8882.30
}
if inrange(`year', 2001,2014) { 
	local employer_rate = 0.07
	local worker_rate = 0.035
	local ceiling_contr = 12*7000
}

*2001
if `year' == 2001 { 
	local minwage = 1752.90
	}
*2002
if `year' == 2002 { 
	local minwage = 1971.40
	}
*2003
if `year' == 2003 { 
	local minwage = 2159.90
	}
*2004
if `year' == 2004 { 
	local minwage = 2366.50
	}
*2005
if `year' == 2005 { 
	local minwage = 2593.20
	}
*2006
if `year' == 2006 { 
	local minwage = 2829.70
	}
*2007
if `year' == 2007 { 
	local minwage = 3087.80
	}
*2008
if `year' == 2008 { 
	local minwage = 3443.00
	}
*2009
if `year' == 2009 { 
	local minwage = 4777.80
	}
*2010
if `year' == 2010 { 
	local minwage = 4779.10
	}
	
*2011
if `year' == 2011 { 
	local minwage = 6121.80
	}
	
*2012
if `year' == 2012 { 
	local minwage = 6377.70
	}
	
*2013
if `year' == 2013 { 
	local minwage = 6770.10
	}

*2014
if `year' == 2014 { 
	local minwage = 7157.50
	}

*Common tax brackets in 2011-2014
if inrange(`year', 2001,2014) {
	local first_bracket = 110000
	local second_bracket = 200000
	local third_bracket = 500000									
}

*2015
if `year' == 2015 {
	local minwage = 7610.90
	
	local first_bracket = 116402
	local second_bracket = 200000
	local third_bracket = 500000									
}

*2016
if `year' == 2016 {
	local minwage = 8077.50
	
	local first_bracket = 141000
	local second_bracket = 215000
	local third_bracket = 500000									
}

*2017
if `year' == 2017 {
	local minwage = 8448.40
	
	local first_bracket = 145667.10
	local second_bracket = 222116.50
	local third_bracket = 516550									
}

*2018
if `year' == 2018 {
	local minwage = 8910.60
	
	local first_bracket = 152557.16
	local second_bracket = 232622.61
	local third_bracket = 540982.82									
}

*2019
if `year' == 2019 {
	local minwage = 9443.24
	
	local first_bracket = 158995.06
	local second_bracket = 242439.28
	local third_bracket = 563812.30									
}

*2020
if `year' == 2020 {
	local minwage = 10022.04
	
	local first_bracket = 165482.06
	local second_bracket = 252330.80
	local third_bracket = 586815.84								
}

